package com.pixelmintdrop.model

/**
 * Represents a game piece with its type, position, and rotation
 */
class GamePiece(val type: GamePieceType) {
    var x: Int = 0
    var y: Int = 0
    var rotation: Int = 0
        private set

    private val blocks: Array<Array<Boolean>> = type.getBlocks()

    fun getWidth(): Int = blocks[0].size

    fun getHeight(): Int = blocks.size

    fun isBlockAt(x: Int, y: Int): Boolean {
        if (x < 0 || x >= getWidth() || y < 0 || y >= getHeight()) return false
        return blocks[y][x]
    }

    fun rotate() {
        rotation = (rotation + 1) % 4
        rotateBlocks()
    }

    private fun rotateBlocks() {
        val width = getWidth()
        val height = getHeight()
        val rotated = Array(width) { Array(height) { false } }

        for (y in 0 until height) {
            for (x in 0 until width) {
                when (rotation) {
                    1 -> rotated[x][height - 1 - y] = blocks[y][x]
                    2 -> rotated[height - 1 - y][width - 1 - x] = blocks[y][x]
                    3 -> rotated[width - 1 - x][y] = blocks[y][x]
                    else -> rotated[y][x] = blocks[y][x]
                }
            }
        }

        blocks.indices.forEach { i ->
            blocks[i] = rotated[i].copyOf()
        }
    }
} 