package com.pixelmintdrop.model

import android.content.Context
import android.content.SharedPreferences

/**
 * Manages game statistics and high scores
 */
class StatsManager(context: Context) {
    companion object {
        private const val PREFS_NAME = "game_stats"
        private const val KEY_HIGH_SCORE = "high_score"
        private const val KEY_TOTAL_GAMES = "total_games"
        private const val KEY_TOTAL_LINES = "total_lines"
        private const val KEY_TOTAL_QUADS = "total_quads"
        private const val KEY_TOTAL_PERFECT_CLEARS = "total_perfect_clears"
        private const val KEY_SESSION_SCORE = "session_score"
        private const val KEY_SESSION_LINES = "session_lines"
        private const val KEY_SESSION_QUADS = "session_quads"
        private const val KEY_SESSION_PERFECT_CLEARS = "session_perfect_clears"
    }

    private val prefs: SharedPreferences = context.getSharedPreferences(PREFS_NAME, Context.MODE_PRIVATE)

    // Session stats
    private var sessionScore = 0
    private var sessionLines = 0
    private var sessionQuads = 0
    private var sessionPerfectClears = 0

    fun getHighScore(): Int = prefs.getInt(KEY_HIGH_SCORE, 0)
    fun getTotalGames(): Int = prefs.getInt(KEY_TOTAL_GAMES, 0)
    fun getTotalLines(): Int = prefs.getInt(KEY_TOTAL_LINES, 0)
    fun getTotalQuads(): Int = prefs.getInt(KEY_TOTAL_QUADS, 0)
    fun getTotalPerfectClears(): Int = prefs.getInt(KEY_TOTAL_PERFECT_CLEARS, 0)

    fun getSessionScore(): Int = sessionScore
    fun getSessionLines(): Int = sessionLines
    fun getSessionQuads(): Int = sessionQuads
    fun getSessionPerfectClears(): Int = sessionPerfectClears

    fun updateStats(score: Int, lines: Int, isQuad: Boolean, isPerfectClear: Boolean) {
        // Update session stats
        sessionScore += score
        sessionLines += lines
        if (isQuad) sessionQuads++
        if (isPerfectClear) sessionPerfectClears++

        // Update high score if needed
        if (sessionScore > getHighScore()) {
            prefs.edit().putInt(KEY_HIGH_SCORE, sessionScore).apply()
        }

        // Update total stats
        prefs.edit()
            .putInt(KEY_TOTAL_LINES, getTotalLines() + lines)
            .putInt(KEY_TOTAL_QUADS, getTotalQuads() + if (isQuad) 1 else 0)
            .putInt(KEY_TOTAL_PERFECT_CLEARS, getTotalPerfectClears() + if (isPerfectClear) 1 else 0)
            .apply()
    }

    fun startNewGame() {
        // Increment total games counter
        prefs.edit().putInt(KEY_TOTAL_GAMES, getTotalGames() + 1).apply()
    }

    fun resetSession() {
        sessionScore = 0
        sessionLines = 0
        sessionQuads = 0
        sessionPerfectClears = 0
    }

    fun resetAllStats() {
        prefs.edit().clear().apply()
        resetSession()
    }
} 